# -*- coding: utf-8 -*-
from setuphelpers import *


def install():
    # Declaring local variables
    if control.architecture == "x64":
        bin_dependencies_to_install = [
            "AppleApplicationSupport.msi",
            "AppleApplicationSupport64.msi",
            "AppleMobileDeviceSupport.msi",
            "AppleMobileDeviceSupport64.msi",
            "Bonjour64.msi",
        ]
        bin_msi_name = "iTunes64.msi"
    else:
        bin_dependencies_to_install = [
            "AppleApplicationSupport.msi",
            "AppleApplicationSupport64.msi",
            "AppleMobileDeviceSupport.msi",
            "AppleMobileDeviceSupport64.msi",
            "Bonjour.msi",
        ]
        bin_msi_name = "iTunes.msi"

    # Installing the package
    for binary in bin_dependencies_to_install:
        if isfile(binary):
            install_msi_if_needed(binary, timeout=800)

    # Skip up-to-date iTunes
    itunes_uptodate = False
    for uninstall_itunes in installed_softwares(name="iTunes"):
        if "Apple Inc." in uninstall_itunes["publisher"]:
            if Version(uninstall_itunes["version"]) == Version(control.get_software_version()):
                itunes_uptodate = True
                app_uninstallkey = uninstall_itunes["key"]

    if not itunes_uptodate:
        install_msi_if_needed(bin_msi_name, name="iTunes", min_version=control.get_software_version())
    else:
        uninstallkey.append(app_uninstallkey)

    print("Disabling: Update Check and Telemetry Apple")
    # Option used : (kParentalFlags_DisableFirstRunWelcomeWindow,kParentalFlags_DisableDiagnostics,kParentalFlags_DisableCheckForUpdates,kParentalFlags_Locked,kParentalFlags_DisableCheckForDeviceUpdates,kParentalFlags_DisableCheckForAppUpdates,kParentalFlags_DisableAutomaticDeviceSync)
    registry_set(HKEY_LOCAL_MACHINE, r"SOFTWARE\Apple Computer, Inc.\iTunes\Parental Controls\Default", "AdminFlags", 23202049, REG_DWORD)

    # Making sure that intrusive Apple's apps are not installed
    for intru_app in ["Apple Software Update"]:
        for uninstall_intru_app in installed_softwares(name=intru_app):
            if "Apple Inc." in uninstall_intru_app["publisher"]:
                print("Removing %s" % uninstall_intru_app["name"])
                run(uninstall_cmd(uninstall_intru_app["key"]))

    # Disable iTunesHelper at Startup
    registry_delete(HKEY_LOCAL_MACHINE, r"SOFTWARE\Microsoft\Windows\CurrentVersion\Run", "iTunesHelper")


# def uninstall():
#     # Uninstalling package
#     for uninstall_itunes_app in installed_softwares("Apple"):
#         if "Apple Inc." in uninstall_itunes_app["publisher"]:
#             if uninstall_itunes_app["name"] in ["Bonjour", "iTunes", "Apple Mobile Device Support"]:
#                 print("Removing: %s (%s)" % (uninstall_itunes_app["name"], uninstall_itunes_app["version"]))
#                 killalltasks(control.get_impacted_process_list())
#                 run(uninstall_cmd(uninstall_itunes_app["key"]))
#                 wait_uninstallkey_absent(uninstall_itunes_app["key"])
